@@ -524,7 +524,8 @@ class GamutCanvas(LUTCanvas):
 												whitepoint_destination=profile.tags.wtpt.ir.values())
 					pcs_triplets.append(color)
 				pcs_triplets.sort()
-			elif profile.version >= 4:
+			elif (profile.version >= 4 and
+				  not profile.convert_iccv4_tags_to_iccv2()):
 				self.profiles[i] = None
 				self.errors.append(Error("\n".join([lang.getstr("profile.iccv4.unsupported"),
 													profile.getDescription()])))
@@ -799,11 +800,11 @@ class GamutViewOptions(wx_Panel):
 		except Exception, exception:
 			safe_print(exception)
 		if srgb:
-			self.comparison_profiles[os.path.basename(srgb.fileName)] = srgb
+			self.comparison_profiles[srgb.getDescription()] = srgb
 		for profile in config.get_standard_profiles():
-			basename = os.path.basename(profile.fileName)
-			if basename not in self.comparison_profiles:
-				self.comparison_profiles[basename] = profile
+			desc = profile.getDescription()
+			if desc not in self.comparison_profiles:
+				self.comparison_profiles[desc] = profile
 		self.comparison_profile_select = wx.Choice(self, -1,
 												   size=(150 * scale, -1), 
 												   choices=[])
@@ -897,10 +898,10 @@ class GamutViewOptions(wx_Panel):
 		except Exception, exception:
 			show_result_dialog(exception, self.TopLevelParent)
 		else:
-			basename = os.path.basename(profile.fileName)
-			self.comparison_profiles[basename] = profile
+			desc = profile.getDescription()
+			self.comparison_profiles[desc] = profile
 			self.comparison_profiles_sort()
-			self.comparison_profile_select.SetSelection(self.comparison_profiles.keys().index(basename))
+			self.comparison_profile_select.SetSelection(self.comparison_profiles.keys().index(desc))
 			self.comparison_profile_select_handler(None)
 
 	def comparison_profile_select_handler(self, event):
@@ -1044,7 +1045,7 @@ class ProfileInfoFrame(LUTFrame):
 		self.plot_mode_select.Bind(wx.EVT_CHOICE, self.plot_mode_select_handler)
 		self.plot_mode_select.Disable()
 		
-		self.tooltip_btn = BitmapButton(p1, -1, geticon(16, "dialog-information"),
+		self.tooltip_btn = BitmapButton(p1, -1, geticon(16, "question-inverted"),
 										style=wx.NO_BORDER)
 		self.tooltip_btn.SetBackgroundColour(BGCOLOUR)
 		self.tooltip_btn.Bind(wx.EVT_BUTTON, self.tooltip_handler)
@@ -1053,7 +1054,7 @@ class ProfileInfoFrame(LUTFrame):
 														wx.LEFT, border=8)
 
 		self.save_plot_btn = BitmapButton(p1, -1,
-										  geticon(16, "camera-photo"),
+										  geticon(16, "image-x-generic-inverted"),
 										  style=wx.NO_BORDER)
 		self.save_plot_btn.SetBackgroundColour(BGCOLOUR)
 		self.save_plot_btn.Bind(wx.EVT_BUTTON, self.SaveFile)
@@ -1160,30 +1161,7 @@ class ProfileInfoFrame(LUTFrame):
 				   border=4)
 		self.show_as_L.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
 		
-		self.toggle_red = CustomCheckBox(self.lut_view_options, -1, "R")
-		self.toggle_red.SetForegroundColour(FGCOLOUR)
-		self.toggle_red.SetValue(True)
-		hsizer.Add(self.toggle_red,
-										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.toggle_red.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
-		
-		hsizer.Add((4, 0))
-		
-		self.toggle_green = CustomCheckBox(self.lut_view_options, -1, "G")
-		self.toggle_green.SetForegroundColour(FGCOLOUR)
-		self.toggle_green.SetValue(True)
-		hsizer.Add(self.toggle_green,
-										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.toggle_green.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
-		
-		hsizer.Add((4, 0))
-		
-		self.toggle_blue = CustomCheckBox(self.lut_view_options, -1, "B")
-		self.toggle_blue.SetForegroundColour(FGCOLOUR)
-		self.toggle_blue.SetValue(True)
-		hsizer.Add(self.toggle_blue,
-										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.toggle_blue.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
+		self.add_toggles(self.lut_view_options, hsizer)
 		
 		self.toggle_clut = CustomCheckBox(self.lut_view_options, -1, "LUT")
 		self.toggle_clut.SetForegroundColour(FGCOLOUR)
@@ -1298,18 +1276,11 @@ class ProfileInfoFrame(LUTFrame):
 				(self.rTRC and
 				 self.gTRC and
 				 self.bTRC) or
-				(("B2A0" in self.profile.tags or
-				  "A2B0" in self.profile.tags) and
-				 self.profile.colorSpace == "RGB")):
-				self.toggle_red.Enable()
-				self.toggle_green.Enable()
-				self.toggle_blue.Enable()
+				("B2A0" in self.profile.tags or
+				 "A2B0" in self.profile.tags)):
 				self.DrawLUT()
 				self.handle_errors()
 			else:
-				self.toggle_red.Disable()
-				self.toggle_green.Disable()
-				self.toggle_blue.Disable()
 				self.client.DrawLUT()
 		self.splitter.GetTopLeft().sizer.Layout()
 		self.splitter.GetTopLeft().Refresh()
@@ -1323,13 +1294,16 @@ class ProfileInfoFrame(LUTFrame):
 									     "\n" + profile), self)
 				self.DrawCanvas(reset=reset)
 				return
+		if (not reset and getattr(self, "profile", None) and
+			self.profile.colorSpace != profile.colorSpace):
+			reset = True
 		self.profile = profile
-		self.rTRC = self.tf_rTRC = profile.tags.get("rTRC",
-													profile.tags.get("kTRC"))
-		self.gTRC = self.tf_gTRC = profile.tags.get("gTRC",
-													profile.tags.get("kTRC"))
-		self.bTRC = self.tf_bTRC = profile.tags.get("bTRC",
-													profile.tags.get("kTRC"))
+		for channel in "rgb":
+			trc = profile.tags.get(channel + "TRC", profile.tags.get("kTRC"))
+			if isinstance(trc, ICCP.ParametricCurveType):
+				trc = trc.get_trc()
+			setattr(self, channel + "TRC", trc)
+			setattr(self, "tf_" + channel + "TRC", trc)
 		self.trc = None
 		
 		self.gamut_view_options.direction_select.Enable("B2A0" in
@@ -1351,48 +1325,28 @@ class ProfileInfoFrame(LUTFrame):
 		self.toggle_clut.SetValue("B2A0" in profile.tags or
 								  "A2B0" in profile.tags)
 		
-		plot_mode = self.plot_mode_select.GetSelection()
-		plot_mode_count = self.plot_mode_select.GetCount()
+		plot_mode = self.plot_mode_select.GetStringSelection()
 		choice = []
 		info = profile.get_info()
 		self.client.errors = []
 		if ((self.rTRC and self.gTRC and self.bTRC) or
-			(("B2A0" in self.profile.tags or "A2B0" in self.profile.tags) and
-			 self.profile.colorSpace == "RGB")):
-			# vcgt needs to be in here for compatibility with LUTFrame
-			choice.append(lang.getstr("vcgt"))
+			(self.toggle_clut.GetValue() and
+			 profile.colorSpace in ("RGB", "GRAY", "CMYK"))):
+			if "vcgt" in profile.tags or "MS00" in profile.tags:
+				choice.append(lang.getstr("vcgt"))
 			try:
 				self.lookup_tone_response_curves()
 			except Exception, exception:
 				wx.CallAfter(show_result_dialog, exception, self)
 			else:
 				choice.append(lang.getstr("[rgb]TRC"))
-		if getcfg("show_advanced_options"):
-			if isinstance(self.profile.tags.get("A2B0"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.A2B0.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.A2B0.shaper_curves.output'))
-			if isinstance(self.profile.tags.get("A2B1"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.A2B1.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.A2B1.shaper_curves.output'))
-			if isinstance(self.profile.tags.get("A2B2"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.A2B2.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.A2B2.shaper_curves.output'))
-			if isinstance(self.profile.tags.get("B2A0"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.B2A0.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.B2A0.shaper_curves.output'))
-			if isinstance(self.profile.tags.get("B2A1"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.B2A1.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.B2A1.shaper_curves.output'))
-			if isinstance(self.profile.tags.get("B2A2"), ICCP.LUT16Type):
-				choice.append(lang.getstr('profile.tags.B2A2.shaper_curves.input'))
-				choice.append(lang.getstr('profile.tags.B2A2.shaper_curves.output'))
+		choice = self.add_shaper_curves(choice)
 		choice.append(lang.getstr("gamut"))
 		self.Freeze()
 		self.plot_mode_select.SetItems(choice)
-		if plot_mode < 0:
-			plot_mode = self.plot_mode_select.GetCount() - 1
-		self.plot_mode_select.SetSelection(min(plot_mode,
-											   self.plot_mode_select.GetCount() - 1))
+		if not self.plot_mode_select.SetStringSelection(plot_mode):
+			self.plot_mode_select.SetSelection(self.plot_mode_select.GetCount() - 1)
+			reset = True
 		self.select_current_page()
 		self.plot_mode_select.Enable()
 		
@@ -1403,6 +1357,8 @@ class ProfileInfoFrame(LUTFrame):
 		lines = []
 		for label, value in info:
 			label = label.replace("\0", "")
+			if value is None:
+				value = ""
 			value = wrap(universal_newlines(value.strip()).replace("\t", "\n"),
 						 52).replace("\0", "").split("\n")
 			linecount = len(value)
@@ -1650,7 +1606,9 @@ class ProfileInfoFrame(LUTFrame):
 		Drag'n'drop handler for .cal/.icc/.icm files.
 		
 		"""
-		self.LoadProfile(path, reset=False)
+		reset = (self.plot_mode_select.GetSelection() ==
+				 self.plot_mode_select.GetCount() - 1)
+		self.LoadProfile(path, reset=reset)
 
 
 	def get_platform_window_size(self, defaultwidth=None, defaultheight=None,
@@ -1724,11 +1682,7 @@ class ProfileInfoFrame(LUTFrame):
 		self.select_current_page()
 		reset = (self.plot_mode_select.GetSelection() ==
 				 self.plot_mode_select.GetCount() - 1)
-		if not reset:
-			self.client.resetzoom()
 		self.DrawCanvas(reset=reset)
-		if not reset:
-			wx.CallAfter(self.client.center)
 		self.Thaw()
 
 	def get_commands(self):
